@@ -90,7 +90,7 @@ class Document(BaseDocument):
         elif type(dct) is list:
             for i, v in enumerate(dct):
                 dct[i] = Document.__dict_key_process(
-                    dct[k], f, *fargs, **fkwargs)
+                    dct[i], f, *fargs, **fkwargs)
             return dct
         else:
             return dct if type(dct) is not ObjectId else str(dct)
@@ -129,12 +129,15 @@ class Document(BaseDocument):
         pass
 
     @staticmethod
-    def __field_verify(spec, dct):
+    def __field_verify(spec, dct, top_level=False):
 
         if type(spec) is dict:
 
             if dct is None:
-                return None
+                if not top_level:
+                    return None
+                else:
+                    return DotDict()
 
             for k, v in DotDict(spec).iteritems():
                 dct[k] = Document.__field_verify(
@@ -147,7 +150,10 @@ class Document(BaseDocument):
         elif type(spec) is list:
 
             if dct is None:
-                return None
+                if not top_level:
+                    return None
+                else:
+                    return []
 
             list_spec = spec[0]
 
@@ -172,16 +178,17 @@ class Document(BaseDocument):
                     dct = ObjectId(dct)
 
                 if not issubclass(type(dct), typ):
-                    raise TypeError
+                    return typ(dct)
 
             return dct
 
     def validate_fields_extra(self, spec):
-        self.__class__.__field_verify(spec, self)
+        self.__class__.__field_verify(spec, self, top_level=True)
 
     def validate_fields(self):
         if '__fields__' in self.__class__.__dict__:
-            self.__class__.__field_verify(self.__class__.__fields__, self)
+            self.__class__.__field_verify(
+                self.__class__.__fields__, self, top_level=True)
 
     def save(self):
         self.validate_fields()
